<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCrossSections</name>
    <message>
      <location filename="../../Command.cpp" line="269"/>
      <source>MeshPart</source>
      <translation>Mrežasti Oblik</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="270"/>
      <source>Cross-sections...</source>
      <translation>Presjeci...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="271"/>
      <source>Cross-sections</source>
      <translation>Presjeci</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="305"/>
      <source>Mesh</source>
      <translation>Mreža</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="306"/>
      <source>Curve on mesh...</source>
      <translation>Krivulja na mreži...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="307"/>
      <source>Creates an approximated curve on top of a mesh.
This command only works with a 'mesh' object.</source>
      <translation>Stvara približnu krivulju na vrhu mreže.
Ova naredba radi samo s 'mrežnim' objektom.</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location filename="../../Command.cpp" line="58"/>
      <source>Mesh</source>
      <translation>Mreža</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="59"/>
      <source>Create mesh from shape...</source>
      <translation>Stvori mrežu od oblika ...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="60"/>
      <source>Tessellate shape</source>
      <translation>Pretvori oblik u mrežu</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location filename="../../Command.cpp" line="185"/>
      <source>Mesh</source>
      <translation>Mreža</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="186"/>
      <source>Create section from mesh and plane</source>
      <translation>Stvori presjek iz mreže i ravnine</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="187"/>
      <source>Section</source>
      <translation>Odsječak</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location filename="../../Command.cpp" line="83"/>
      <source>Mesh</source>
      <translation>Mreža</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="84"/>
      <source>Trim mesh with a plane</source>
      <translation>Obrezivanje mreže s ravninom</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="85"/>
      <location filename="../../Command.cpp" line="86"/>
      <source>Trims a mesh with a plane</source>
      <translation>Obrezuje mrežu s ravninom</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../Command.cpp" line="129"/>
      <source>Trim with plane</source>
      <translation>Skraćivanje sa ravninom</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="208"/>
      <source>Section with plane</source>
      <translation>Presjek s ravninom</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CrossSections</name>
    <message>
      <location filename="../../CrossSections.ui" line="14"/>
      <source>Cross sections</source>
      <translation>Presjeci</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="20"/>
      <source>Guiding plane</source>
      <translation>Vodeća površina</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="26"/>
      <source>XY</source>
      <translation>XY</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="36"/>
      <source>XZ</source>
      <translation>XZ</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="43"/>
      <source>YZ</source>
      <translation>YZ</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="52"/>
      <source>Position:</source>
      <translation>Položaj:</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="71"/>
      <source>Sections</source>
      <translation>Odjeljci</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="83"/>
      <source>On both sides</source>
      <translation>S obje strane</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="92"/>
      <source>Count</source>
      <translation>Broj</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="109"/>
      <source>Distance:</source>
      <translation>Udaljenost:</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="128"/>
      <source>Options</source>
      <translation>Mogućnosti</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="134"/>
      <source>Connect edges if distance less than</source>
      <translation>Spojite rubove ako je udaljenost manja od</translation>
    </message>
    <message>
      <location filename="../../CrossSections.cpp" line="366"/>
      <source>Failure</source>
      <translation>Neuspjeh</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="364"/>
      <source>Create</source>
      <translation>Stvoriti</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="366"/>
      <source>Close wire</source>
      <translation>Zatvori žicu</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="368"/>
      <source>Clear</source>
      <translation>Brisanje</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="369"/>
      <source>Cancel</source>
      <translation>Otkazati</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="615"/>
      <source>Wrong mesh picked</source>
      <translation>Izabrana pogrešna mreža</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="655"/>
      <source>No point was picked</source>
      <translation>Ni jedan vrh nije odabran</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="14"/>
      <source>Curve on mesh</source>
      <translation>Krivulja na mreži</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="23"/>
      <source>Press 'Start', then pick points on the mesh; when enough points have been set, right-click and choose 'Create'. Repeat this process to create more splines. Close this task panel to complete the operation.

This command only works with a 'mesh' object, not a regular face or surface. To convert an object to a mesh use the tools of the Mesh Workbench.</source>
      <translation>Pritisnite "Start", a zatim odaberite točke na mreži; kada se postavi dovoljno točaka, kliknite desnu tipku miša i odaberite 'Stvori'. Ponovite ovaj postupak da biste stvorili više zavoja. Zatvorite ovu ploču zadataka da biste dovršili operaciju.

Ova naredba radi samo s  'mreža', objektom a ne s uobičajenim licem ili površinom. Za pretvaranje objekta u mrežu koristite alate radne površine Mreža</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="38"/>
      <source>Wire</source>
      <translation>Žica</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="44"/>
      <source>Snap tolerance to vertices</source>
      <translation>Tolerancija kod Prikvači na vrhove</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="51"/>
      <source> px</source>
      <translation> px</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="61"/>
      <source>Split threshold</source>
      <translation>Granična vrijednost razdjeljivanja</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="87"/>
      <source>Spline Approximation</source>
      <translation>Kriva aproksimacija</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="96"/>
      <source>Tolerance to mesh</source>
      <translation>Odstupanje na mreži</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="122"/>
      <source>Continuity</source>
      <translation>Kontinuitet</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="136"/>
      <source>Maximum curve degree</source>
      <translation>Maksimalni Stupanj krivulje</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="153"/>
      <source>Start</source>
      <translation>Počni</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="14"/>
      <source>Tessellation</source>
      <translation>Mozaik</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="20"/>
      <source>Meshing options</source>
      <translation>Opcije mreže</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="30"/>
      <source>Standard</source>
      <translation>Standard</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="33"/>
      <source>Use the standard mesher</source>
      <translation>Koristite standardnu izgradnju mreže</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="41"/>
      <source>Surface deviation:</source>
      <translation>Odstupanje površine:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="48"/>
      <source>Maximal linear deflection of a mesh section from the surface of the object</source>
      <translation>Maksimalni linearni otklon mrežnog odjeljka od površine objekta</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="67"/>
      <source>Angular deviation:</source>
      <translation>Kutna odstupanja:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="74"/>
      <source>Maximal angular deflection of a mesh section to the next section</source>
      <translation>Maksimalni kutni otklon mrežnog odjeljka do slijedećeg odjeljka</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="98"/>
      <source>The maximal linear deviation of a mesh segment will be the specified
Surface deviation multiplied by the length of the current mesh segment (edge)</source>
      <translation>Maksimalno linearno odstupanje mrežnog segmenta bit će specificirano
Površinsko odstupanje pomnoženo s dužinom trenutnog segmenta mreže (ruba)
</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="102"/>
      <source>Relative surface deviation</source>
      <translation>Relativno odstupanje površine</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="109"/>
      <source>Mesh will get face colors of the object</source>
      <translation>Mreža će dobiti boje lica objekta</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="112"/>
      <source>Apply face colors to mesh</source>
      <translation>Dodaje boju lica na mrežu</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="119"/>
      <source>Mesh segments will be grouped according to the color of the object faces.
These groups will be exported for mesh output formats supporting
this feature (e.g. the format OBJ).</source>
      <translation>Segmenti mreže će se grupirati prema boji lica objekta.
Ove će se skupine izvoziti za podršku izlaznih formata mreža
ove značajke (npr. format OBJ).
</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="124"/>
      <source>Define segments by face colors</source>
      <translation>Odredi segmente po boji naličja</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="145"/>
      <source>Mefisto</source>
      <translation>Mefisto</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="148"/>
      <source>Use the Mefisto mesher</source>
      <translation>Koristite Mefisto izgradnju mreže</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="156"/>
      <source>Maximum edge length:</source>
      <translation>Maksimalna dužina ruba:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="162"/>
      <source>If this number is smaller the mesh becomes finer.
The smallest value is 0.</source>
      <translation>Ako je taj broj manji, mreža postaje finija.
Najmanja vrijednost je 0</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="183"/>
      <source>Estimate</source>
      <translation>Procjena</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="206"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="209"/>
      <source>Use the Netgen mesher</source>
      <translation>Koristite Netgen izgradnju mreže</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="217"/>
      <source>Fineness:</source>
      <translation>Finoća:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="234"/>
      <source>Very coarse</source>
      <translation>Jako grubo</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="239"/>
      <source>Coarse</source>
      <translation>Grubo</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="244"/>
      <source>Moderate</source>
      <translation>Srednje grubo</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="249"/>
      <source>Fine</source>
      <translation>Fino</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="254"/>
      <source>Very fine</source>
      <translation>Jako fino</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="259"/>
      <source>User defined</source>
      <translation>Korisnički određeno</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="269"/>
      <source>Mesh size grading:</source>
      <translation>Veličina Mreže stupnjevanje:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="279"/>
      <source>If this parameter is smaller, the mesh becomes finer.
A value in the range of 0.1-1.</source>
      <translation>Ako je ovaj parametar manji, mreža postaje finija.
Vrijednost u rasponu 0.1-1.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="302"/>
      <source>Elements per edge:</source>
      <translation>Elemenata po rubu:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="312"/>
      <location filename="../../Tessellation.ui" line="345"/>
      <source>If this parameter is larger, the mesh becomes finer.
A value in the range of 0.2-10.</source>
      <translation>Ako je ovaj parametar manji, mreža postaje finija.
Vrijednost u rasponu 0.2-10.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="335"/>
      <source>Elements per curvature radius:</source>
      <translation>Elemenata po radijusu zakrivljenosti:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="370"/>
      <source>Whether optimization of surface shape will be done</source>
      <translation>Hoće li se izvršiti optimizacija oblika površine</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="373"/>
      <source>Optimize surface</source>
      <translation>Optimizirati površinu</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="383"/>
      <source>Whether second order elements will be generated</source>
      <translation>Hoće li se generirati elementi drugog reda</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="386"/>
      <source>Second order elements</source>
      <translation>Drugi red elemenata</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="393"/>
      <source>Whether meshes will be arranged preferably using quadrilateral faces</source>
      <translation>Hoće li se mreže urediti po mogućnosti pomoću četverokutnih lica
</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="396"/>
      <source>Quad dominated</source>
      <translation>Quad dominira</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="422"/>
      <source>Leave panel open</source>
      <translation>Ostavite prozor otvoren</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="61"/>
      <source>Gmsh</source>
      <translation>Gmsh</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="225"/>
      <location filename="../../Tessellation.cpp" line="231"/>
      <source>No active document</source>
      <translation>Nema aktivnog dokumenta</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="259"/>
      <source>You have selected a body without tip.
Either set the tip of the body or select a different shape, please.</source>
      <translation>Odabrali ste tijelo bez vrha.
Postavite vrh tijela ili odaberite drugi oblik, molim.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="263"/>
      <source>You have selected a shape without faces.
Select a different shape, please.</source>
      <translation>Odabrali ste oblik bez naličja.
Odaberite drugačiji oblik, molim.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="267"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Prvo daberite oblik za umrežavanje.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="198"/>
      <source>Select plane</source>
      <translation>Odaberite ravninu</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="199"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation>Molimo odaberite ravninu na kojoj se dijeli mreža.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location filename="../../Command.cpp" line="95"/>
      <source>Select plane</source>
      <translation>Odaberite ravninu</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="96"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Molimo odaberite ravninu na kojoj se skraćuje mreža.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="102"/>
      <source>Trim by plane</source>
      <translation>Skraćivanje sa ravninom</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="103"/>
      <source>Select the side you want to keep.</source>
      <translation>Odaberite stranu koju želite zadržati.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="104"/>
      <source>Below</source>
      <translation>Ispod</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Above</source>
      <translation>Iznad</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Split</source>
      <translation>Razdjeli</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="36"/>
      <source>MeshPart</source>
      <translation>Mrežasti Oblik</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_CreateFlatMesh</name>
    <message>
      <location filename="../../MeshFlatteningCommand.py" line="47"/>
      <source>Unwrap Mesh</source>
      <translation>Raširi Mrežu</translation>
    </message>
    <message>
      <location filename="../../MeshFlatteningCommand.py" line="50"/>
      <source>Find a flat representation of a mesh.</source>
      <translation>Pronađite ravni prikaz mreže.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_CreateFlatFace</name>
    <message>
      <location filename="../../MeshFlatteningCommand.py" line="79"/>
      <source>Unwrap Face</source>
      <translation>Raširi Lice</translation>
    </message>
    <message>
      <location filename="../../MeshFlatteningCommand.py" line="82"/>
      <source>Find a flat representation of a face.</source>
      <translation>Pronađite ravni prikaz lica.</translation>
    </message>
  </context>
</TS>
